

#' attendance.table
#'
#' Example data to create attendance certificates
#'
#' @md
#' @details
#' A data frame with the name of attendees
#' ```{r echo=FALSE}
#' knitr::kable(attendance.table)
#' ```
#'
"attendance.table"


#' badges.table
#'
#' Example data to create identification badges
#'
#' @md
#' @details
#' ```{r echo=FALSE}
#' knitr::kable(badges.table)
#' ```
#'
"badges.table"


#' herbarium.table
#'
#' Example data to create herbarium labels
#'
#' @md
#' @details
#' ```{r echo=FALSE}
#' knitr::kable(herbarium.table)
#' ```
#'
"herbarium.table"


#' collection.table
#'
#' Example data to create collection labels
#'
#' @md
#' @details
#' ```{r echo=FALSE}
#' knitr::kable(collection.table)
#' ```
#'
"collection.table"


#' participation.table
#'
#' Example data to create participation certificates
#'
#' @md
#' @details
#' ```{r echo=FALSE}
#' knitr::kable(participation.table)
#' ```
#'
"participation.table"


#' tiny.table
#'
#' Example data to create tinylabels
#'
#' @md
#' @details
#' ```{r echo=FALSE}
#' knitr::kable(tiny.table)
#' ```
#'
"tiny.table"



#' abstract.table
#'
#' Example data to create abstract books
#'
#' @md
#' @details
#' ```{r echo=FALSE}
#' knitr::kable(abstract.table)
#' ```
#'
"abstract.table"



#' multichoice.table
#'
#' Example data to create multiple choice tests
#'
#' @md
#' @details
#' ```{r echo=FALSE}
#' knitr::kable(multichoice.table)
#' ```
#'
"multichoice.table"

